==> haskell-base64-0.4.2.4-138-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-base64.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 base64
version:              0.4.2.4
visibility:           public
id:                   base64-0.4.2.4-HWZ73VAsfNIJNyyuoFSC67
key:                  base64-0.4.2.4-HWZ73VAsfNIJNyyuoFSC67
license:              BSD-3-Clause
copyright:            (c) 2019-2022 Emily Pillmore
maintainer:           emilypi@cohomolo.gy
author:               Emily Pillmore
homepage:             https://github.com/emilypi/base64
synopsis:             A modern RFC 4648-compliant Base64 library
description:
    RFC 4648-compliant Base64 with an eye towards performance and modernity (additional support for RFC 7049 standards)

category:             Data
abi:                  347fcdb3d943fc329e2e11b09ccad7cf
exposed:              True
exposed-modules:
    Data.ByteString.Base64 Data.ByteString.Base64.URL
    Data.ByteString.Lazy.Base64 Data.ByteString.Lazy.Base64.URL
    Data.ByteString.Short.Base64 Data.ByteString.Short.Base64.URL
    Data.Text.Encoding.Base64 Data.Text.Encoding.Base64.Error
    Data.Text.Encoding.Base64.URL Data.Text.Lazy.Encoding.Base64
    Data.Text.Lazy.Encoding.Base64.URL Data.Text.Short.Encoding.Base64
    Data.Text.Short.Encoding.Base64.URL

hidden-modules:
    Data.ByteString.Base64.Internal
    Data.ByteString.Base64.Internal.Head
    Data.ByteString.Base64.Internal.Tables
    Data.ByteString.Base64.Internal.Tail
    Data.ByteString.Base64.Internal.Utils
    Data.ByteString.Base64.Internal.W16.Loop
    Data.ByteString.Base64.Internal.W32.Loop
    Data.ByteString.Base64.Internal.W64.Loop

import-dirs:          /usr/lib/ghc-9.4.8/site-local/base64-0.4.2.4
library-dirs:         /usr/lib/ghc-9.4.8/site-local/base64-0.4.2.4
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/base64-0.4.2.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-base64
hs-libraries:         HSbase64-0.4.2.4-HWZ73VAsfNIJNyyuoFSC67
depends:
    base-4.17.2.1 bytestring-0.11.5.3 deepseq-1.4.8.0 text-2.0.2
    text-short-0.1.6-Iw5qJriXjnZ5HQscs86bYL

haddock-interfaces:   /usr/share/doc/haskell-base64/html/base64.haddock
haddock-html:         /usr/share/doc/haskell-base64/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-base64-0.4.2.4-139-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-base64.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 base64
version:              0.4.2.4
visibility:           public
id:                   base64-0.4.2.4-6iHGjk0amyXDtKFouPcRCt
key:                  base64-0.4.2.4-6iHGjk0amyXDtKFouPcRCt
license:              BSD-3-Clause
copyright:            (c) 2019-2022 Emily Pillmore
maintainer:           emilypi@cohomolo.gy
author:               Emily Pillmore
homepage:             https://github.com/emilypi/base64
synopsis:             A modern RFC 4648-compliant Base64 library
description:
    RFC 4648-compliant Base64 with an eye towards performance and modernity (additional support for RFC 7049 standards)

category:             Data
abi:                  493dc667bf9c977caf8e5c7fe6513681
exposed:              True
exposed-modules:
    Data.ByteString.Base64 Data.ByteString.Base64.URL
    Data.ByteString.Lazy.Base64 Data.ByteString.Lazy.Base64.URL
    Data.ByteString.Short.Base64 Data.ByteString.Short.Base64.URL
    Data.Text.Encoding.Base64 Data.Text.Encoding.Base64.Error
    Data.Text.Encoding.Base64.URL Data.Text.Lazy.Encoding.Base64
    Data.Text.Lazy.Encoding.Base64.URL Data.Text.Short.Encoding.Base64
    Data.Text.Short.Encoding.Base64.URL

hidden-modules:
    Data.ByteString.Base64.Internal
    Data.ByteString.Base64.Internal.Head
    Data.ByteString.Base64.Internal.Tables
    Data.ByteString.Base64.Internal.Tail
    Data.ByteString.Base64.Internal.Utils
    Data.ByteString.Base64.Internal.W16.Loop
    Data.ByteString.Base64.Internal.W32.Loop
    Data.ByteString.Base64.Internal.W64.Loop

import-dirs:          /usr/lib/ghc-9.4.8/site-local/base64-0.4.2.4
library-dirs:         /usr/lib/ghc-9.4.8/site-local/base64-0.4.2.4
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/base64-0.4.2.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-base64
hs-libraries:         HSbase64-0.4.2.4-6iHGjk0amyXDtKFouPcRCt
depends:
    base-4.17.2.1 bytestring-0.11.5.3 deepseq-1.4.8.0 text-2.0.2
    text-short-0.1.6-E7dU7XggPrS2MqFRVhPPLu

haddock-interfaces:   /usr/share/doc/haskell-base64/html/base64.haddock
haddock-html:         /usr/share/doc/haskell-base64/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
